import 'package:tf_custom_widgets/utils/WidgetUtils.dart';
import 'package:flutter/material.dart';
import 'package:tf_custom_widgets/widgets/MyText.dart';
import 'custom_dropDown/CustomDropDown.dart';

class DropdownTextField<DataType> extends StatefulWidget {
  final dynamic data;
  final GlobalKey? dropKey;
  final String? label;
  final String? hint;
  final DataType? selectedItem;
  final bool showSelectedItem;
  final EdgeInsets? margin;
  final double? fontSize;
  final double? labelSize;
  final dynamic validate;
  final dynamic onChange;
  final dynamic finData;
  final EdgeInsets? downIconPadding;
  final bool useName;
  final Color? enableColor;
  final Color? hintColor;
  final Color? buttonsColor;

  DropdownTextField(
      {this.label,
        this.hint,
        this.margin,
        this.validate,
        this.downIconPadding,
        this.useName = true,
        this.onChange,
        this.fontSize,
        this.labelSize,
        this.hintColor,
        this.buttonsColor,
        this.finData,
        this.dropKey,
        this.data,
        this.enableColor,
        this.selectedItem,
        this.showSelectedItem = false});

  @override
  _DropdownTextFieldState<DataType> createState() =>
      _DropdownTextFieldState<DataType>();
}

class _DropdownTextFieldState<DataType> extends State<DropdownTextField> {
  @override
  Widget build(BuildContext context) {
    return Container(
      margin: widget.margin ?? EdgeInsets.zero,
      child: DropdownSearch<DataType>(
        key: widget.dropKey,
        mode: Mode.BOTTOM_SHEET,
        isFilteredOnline: false,
        maxHeight: 300,
        label: widget.label,
        items: widget.data,
        onFind: widget.finData,
        validator: widget.validate,
        onChanged: widget.onChange,
        showSearchBox: true,
        showClearButton: true,
        clearButton: Icon(Icons.clear, size: 24,color: widget.buttonsColor?? Colors.black),
        dropDownButton: Icon(Icons.arrow_drop_down, size: 24,color: widget.buttonsColor?? Colors.black),
        selectedItem: widget.selectedItem,
        itemAsString: (dynamic u) => widget.useName ? u.name : u,
        showSelectedItem: widget.showSelectedItem,
        style: WidgetUtils.textStyle,
        searchBoxStyle: WidgetUtils.textStyle,
        searchBoxDecoration: WidgetUtils.setInputDecoration(
            hint: "بحث",
            enableColor: Colors.black,
            padding: EdgeInsets.symmetric(horizontal: 10, vertical: 5)
        ),
        popupTitle: Container(
          height: 50,
          decoration: BoxDecoration(
            color: WidgetUtils.primaryColor,
          ),
          child: Center(
            child: MyText(
              title: widget.label!=null?widget.label!:widget.hint!,
              size: 16,
              color: Colors.white,
            ),
          ),
        ),
        dropdownSearchDecoration: WidgetUtils.setInputDecoration(
            hint: widget.hint,
            hintColor: widget.hintColor,
            label: widget.label,
            enableColor: widget.enableColor?? Colors.black,
            padding: EdgeInsets.symmetric(horizontal: 10, vertical: 5)
        ),
      ),
    );
  }
}
