import 'dart:async';
import 'package:tf_custom_widgets/widgets/MyText.dart';
import 'package:tf_custom_widgets/utils/WidgetUtils.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:multi_select_flutter/multi_select_flutter.dart';



class MultiDropDownField<T> extends StatefulWidget {
  final List<T>? data;
  final List<T> selectedItems;
  final String title;
  final String label;
  final Function(List<T>) onConfirm;
  final Function(T) onItemClick;
  final Future<List<T>> Function()? onFind;

  const MultiDropDownField({
    this.data,
    required this.selectedItems,
    required this.title,
    required this.label,
    required this.onConfirm,
    required this.onItemClick,
    this.onFind,
  });

  @override
  _MultiDropDownField2State<T> createState() => _MultiDropDownField2State<T>();
}

class _MultiDropDownField2State<T> extends State<MultiDropDownField<T>> {

  final StreamController<List<T>> _itemsStream = StreamController<List<T>>();
  late List<T> items;


  @override
  void initState() {
    items=widget.data??[];
    if (widget.onFind!=null) {
      setItemsToStream();
    }else{
      _itemsStream.add(items);
    }
    super.initState();
  }

  setItemsToStream()async{
    var data = await widget.onFind!.call();
    _itemsStream.add(data);
  }


  @override
  Widget build(BuildContext context) {
    var lang = WidgetUtils.lang;
    return  StreamBuilder<List<T>>(
        stream: _itemsStream.stream,
        builder: (context, snapshot) {
          if (snapshot.hasData&&snapshot.data!=null) {
            return MultiSelectBottomSheetField<T>(
              initialChildSize: 0.5,
              listType: MultiSelectListType.LIST,
              searchable: true,
              buttonText: Text(widget.label,style: WidgetUtils.textStyle.copyWith(color:Colors.black54),),
              title: MyText(title: widget.title, color: Colors.black, size: 12),
              decoration: BoxDecoration(
                  color: Colors.white,
                  borderRadius: BorderRadius.circular(8),
                  border: Border.all(color: Colors.grey.withOpacity(.5))
              ),
              items: snapshot.data!.map((e) => MultiSelectItem<T>(e, e.toString())).toList(),
              onConfirm: widget.onConfirm,
              initialValue: widget.selectedItems,
              buttonIcon: Icon(Icons.arrow_drop_down,size: 25,color: Colors.black,),
              confirmText: Text("تآكيد",style: WidgetUtils.textStyle.copyWith(color: WidgetUtils.primaryColor),),
              cancelText: Text("الغاء",style: WidgetUtils.textStyle.copyWith(color: WidgetUtils.primaryColor),),
              chipDisplay: MultiSelectChipDisplay(
                alignment: lang=="ar"? Alignment.topRight : Alignment.topLeft ,
                onTap: widget.onItemClick,
              ),
              validator: (values) {
                if (values == null || values.isEmpty) {
                  return lang=="ar"? "حدد عنصر واحد علي الاقل" : "select at least one";
                }
                return null;
              },
            );
          }
          return Container(
            height: 80,
            width: MediaQuery.of(context).size.width,
            alignment: Alignment.center,
            child: CupertinoActivityIndicator(),
          );

        }
    );
  }
}





